package com.fs.hospital.mapper;

import java.util.List;
import com.fs.hospital.domain.HospitalLogininfor;

/**
 * 系统访问记录Mapper接口
 * 
 * @author fs
 * @date 2024-02-26
 */
public interface HospitalLogininforMapper 
{
    /**
     * 查询系统访问记录
     * 
     * @param infoId 系统访问记录主键
     * @return 系统访问记录
     */
    public HospitalLogininfor selectHospitalLogininforByInfoId(Long infoId);

    /**
     * 查询系统访问记录列表
     * 
     * @param hospitalLogininfor 系统访问记录
     * @return 系统访问记录集合
     */
    public List<HospitalLogininfor> selectHospitalLogininforList(HospitalLogininfor hospitalLogininfor);

    /**
     * 新增系统访问记录
     * 
     * @param hospitalLogininfor 系统访问记录
     * @return 结果
     */
    public int insertHospitalLogininfor(HospitalLogininfor hospitalLogininfor);

    /**
     * 修改系统访问记录
     * 
     * @param hospitalLogininfor 系统访问记录
     * @return 结果
     */
    public int updateHospitalLogininfor(HospitalLogininfor hospitalLogininfor);

    /**
     * 删除系统访问记录
     * 
     * @param infoId 系统访问记录主键
     * @return 结果
     */
    public int deleteHospitalLogininforByInfoId(Long infoId);

    /**
     * 批量删除系统访问记录
     * 
     * @param infoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHospitalLogininforByInfoIds(Long[] infoIds);
}
